/** https://core.telegram.org/bots/api#markdownv2-style */
export const parse_mode = "MarkdownV2";
function escapeInternal(text, escapeChars) {
    return text.replace(new RegExp(`[${escapeChars}\\\\]`, "g"), "\\$&");
}
/** Escape the input text to be displayed as it is */
export function escape(text) {
    return text.replace(/[_*[\]()~`>#+\-=|{}.!\\]/g, "\\$&");
}
/** Format the input text bold */
export function bold(text) {
    return `*${text}*`;
}
/** Format the input text italic */
export function italic(text) {
    return `_${text}_`;
}
/** Strikethrough the input text */
export function strikethrough(text) {
    return `~${text}~`;
}
/** Underline the input text */
export function underline(text) {
    return `__${text}__`;
}
/** Format the input text as blockquote */
export function blockquote(text) {
    const lines = text.split("\n");
    return lines.map((o) => ">" + o).join("\n");
}
/** Format the input text as spoiler */
export function spoiler(text) {
    return `||${text}||`;
}
/** Create a custom Telegram Emoji.
 *
 * A valid emoji must be used as the fallback. The emoji will be shown instead of the custom emoji in places where a custom emoji cannot be displayed (e.g., system notifications) or if the message is forwarded by a non-premium user. It is recommended to use the emoji from the emoji field of the custom emoji sticker.
 * Custom emoji entities can only be used by bots that purchased additional usernames on Fragment.
 */
export function tgEmoji(fallback, emojiId) {
    return `![${fallback}](tg://emoji?id=${emojiId})`;
}
/** Format the input text as monospace */
export function monospace(text) {
    return "`" + escapeInternal(text, "`") + "`";
}
/** Format the input text as a monospace block optionally with a programming language */
export function monospaceBlock(text, programmingLanguage) {
    let result = "";
    result += "```";
    if (programmingLanguage) {
        result += programmingLanguage;
    }
    result += "\n";
    result += escapeInternal(text, "`");
    result += "\n";
    result += "```";
    return result;
}
/** Create an url with a label text */
export function url(label, url) {
    return `[${label}](${escapeInternal(url, ")")})`;
}
/** Create a user mention with a label text */
export function userMention(label, userId) {
    return url(label, `tg://user?id=${userId}`);
}
